<?php

App::uses('ModelBehavior', 'Model');

class CustomFieldsBehavior extends ModelBehavior
{

    /**
     * define an afterFind to retrieve hte custom field data for the item
     *
     * @param Model $model Model using this behavior
     * @param mixed $results The results of the find operation
     * @param bool $primary Whether this model is being queried directly (vs. being queried as an association)
     * @return mixed An array value will replace the value of $results - any other value will be ignored.
     */
    public function afterFind(Model $Model, $results, $primary = false)
    {
        // get all the model ids
        $modelIds = Hash::extract($results, '{n}.' . $Model->alias . '.' . $Model->primaryKey);

        if (empty($modelIds)) {

            return $results;
        }

        // get all the fields and data where id IN model_id
        $Field = EvClassRegistry::init('EvCustomFields.Field');
        $fields = $Field->find(
            'all',
            array(
                'contain' => array('FieldData'),
                'conditions' => array(
                    'model' => EvClassRegistry::getNameFromModel($Model),
                    'model_id' => $modelIds
                )
            )
        );
        $customFields = Hash::combine(
            $fields,
            '{n}.Field.id',
            '{n}',
            '{n}.Field.model_id'
        );

        // loop the results and assign the field data to the result
        foreach ($results as $key => $item) {

            if (empty($item[$Model->alias][$Model->primaryKey])) {
                continue;
            }


            if (! empty($customFields[$item[$Model->alias][$Model->primaryKey]])) {
                $results[$key]['CustomFields'] = $customFields[$item[$Model->alias][$Model->primaryKey]];
            }
        }

        return $results;
    }
}
